@@ -30,10 +30,11 @@ import dbus
 import dbus.service
 import dbus.mainloop.glib
 from gi.repository import GObject
-import apt
-import aptsources.sourceslist
-import apt_pkg
+#import apt
+#import aptsources.sourceslist
+#import apt_pkg
 import threading
+import thread
 from server import PolicyKitService
 from policykit import UK_ACTION_YOUKER
 import time
@@ -41,8 +42,8 @@ import cleaner
 from detailinfo.cpuinfo import DetailInfo
 from beautify.sound import Sound
 from beautify.others import Others
-from appcollections.monitorball.monitor_ball import MonitorBall
-from softwarecenter.apt_daemon import AptDaemon
+#from appcollections.monitorball.monitor_ball import MonitorBall
+#from softwarecenter.apt_daemon import AptDaemon
 from beautify.theme import Theme
 log = logging.getLogger('Daemon')
 
@@ -50,21 +51,73 @@ log = logging.getLogger('Daemon')
 INTERFACE = 'com.ubuntukylin.youker'
 UKPATH = '/'
 
+#------------------------------------apt start----------------------------
+from apt_handler import AppActions, AptHandler, WorkitemError
+#class WorkItem:
+#     def __init__(self, pkgname, action, kwargs):
+#        self.pkgname = pkgname
+#        self.action = action
+#        self.kwargs = kwargs
+
+#class WorkThread(threading.Thread):
+#    def __init__(self, dbusDaemon):
+#        threading.Thread.__init__(self)
+#        self.dbusDaemon = dbusDaemon
+#        print "$$$$$$$$$$$$$$ ", type(self.dbusDaemon)
+
+#    def run(self):
+#        while(True):
+#            if len(self.dbusDaemon.worklist) == 0:
+#                time.sleep(0.2)
+#                continue
+
+#            self.dbusDaemon.mutex.acquire()
+#            item = self.dbusDaemon.worklist.pop(0)  #get first item and remove it from list
+#            self.dbusDaemon.mutex.release()
+
+#            try:
+#                func = getattr(self.dbusDaemon.aptHandler, item.action)
+#                if func is None:
+#                    print "Error action: ", item
+
+#                res = func(item.pkgname,item.kwargs)
+#                if res is False:
+#                    print "Action exec failed..."
+#            except WorkitemError as e:
+#                kwarg = {"apt_appname": item.pkgname,
+#                        "apt_percent": str(-e.errornum),
+#                        "action": str(item.action),
+#                        }
+#                self.dbusDaemon.youker_apt_signal("apt_error", kwarg)
+
+#            time.sleep(0.3)
+#------------------------------------apt end----------------------------
+
 class Daemon(PolicyKitService):
     def __init__ (self, bus, mainloop):
         self.infoconf = DetailInfo()
         self.otherconf = Others()
         self.soundconf = Sound()
-        self.ballconf = MonitorBall()
+#        self.ballconf = MonitorBall()
         self.themeconf = Theme()
-        self.daemonsame = cleaner.SearchTheSame()
-        self.daemonlarge = cleaner.ManageTheLarge()
-        self.daemonunneed = cleaner.CleanTheUnneed()
-        self.daemonclean = cleaner.FunctionOfClean()
+#        self.daemonsame = cleaner.SearchTheSame()
+#        self.daemonlarge = cleaner.ManageTheLarge()
+#        self.daemonunneed = cleaner.CleanTheUnneed()
+#        self.daemonclean = cleaner.FunctionOfClean()
         self.daemononekey = cleaner.OneKeyClean()
-        self.daemoncache = cleaner.CleanTheCache()
-        self.daemonApt = AptDaemon()
+#        self.daemoncache = cleaner.CleanTheCache()
+#        self.daemonApt = AptDaemon()
         #self.daemonApt = AptDaemon(self)
+
+        #--------------apt start----------------
+        self.aptHandler = AptHandler(self)
+#        self.worklist = []
+#        self.mutex = threading.RLock()
+#        self.worker_thread = WorkThread(self)
+#        self.worker_thread.setDaemon(True)
+#        self.worker_thread.start()
+        #--------------apt end----------------
+
         bus_name = dbus.service.BusName(INTERFACE, bus=bus)
         PolicyKitService.__init__(self, bus_name, UKPATH)
         self.mainloop = mainloop
@@ -73,10 +126,115 @@ class Daemon(PolicyKitService):
     def exit(self):
         self.mainloop.quit()
 
+    #--------------apt start----------------
+#    def add_worker_item(self, item):
+#        print "####add_worker_item:", item
+#        self.mutex.acquire()
+#        self.worklist.append(item)
+#        self.mutex.release()
+
+    # package download status signal
+    '''parm mean
+        type:
+            start:start download
+            stop:all work is finish
+            done:all items download finished
+            fail:download failed
+            fetch:one item download finished
+            pulse:download status, this msg given a string like dict
+        msg:
+            a message of type, sometimes is None
+    '''
+    @dbus.service.signal(INTERFACE, signature='sas')
+    def youker_fetch_signal(self, type, msg):
+        pass
+
+    # package install/update/remove signal
+    '''parm mean
+        type:
+            start:start work
+            stop:work finish
+            error:got a error
+            pulse:work status, this msg given a string like dict
+        msg:
+            a message of type, sometimes is None
+    '''
+    @dbus.service.signal(INTERFACE, signature='sas')
+    def youker_apt_signal(self, type, msg):
+        pass
+
+    def start_install_uk(self, pkgName):
+        self.aptHandler.install(pkgName)
+
+    # install package sa:youker_fetch_signal() and youker_apt_signal()
+    #sudo apt-get install youker-assistant=1.3.1-0ubuntu1
+    @dbus.service.method(INTERFACE, in_signature='s', out_signature='b', sender_keyword='sender')
+    def install(self, pkgName, sender=None):
+        print "####install: ",pkgName
+#        item = WorkItem(pkgName, AppActions.INSTALL, None)
+#        self.add_worker_item(item)
+#        self.aptHandler.install(pkgName)
+        thread.start_new_thread(self.start_install_uk, (pkgName,))
+        print "####install return"
+        return True
+
+    def start_update_source_list(self):
+        self.aptHandler.update()
+
+    @dbus.service.method(INTERFACE, in_signature='', out_signature='b', sender_keyword='sender')
+    def update(self, sender=None):
+        thread.start_new_thread(self.start_update_source_list, ())
+#        self.aptHandler.update()
+        return True
+
+#    @dbus.service.method(INTERFACE, in_signature='as', out_signature='b', sender_keyword='sender')
+#    def upgrade(self, pkgNames, sender=None):
+#        print "####upgrade: ", pkgNames
+#        item = WorkItem(pkgNames, AppActions.UPGRADE, None)
+#        self.add_worker_item(item)
+#        #        self.aptHandler.upgrade_pkg(pkgName)
+#        print "####upgrade return"
+#        return True
+    #--------------apt end----------------
+
+
     @dbus.service.method(INTERFACE, in_signature='s', out_signature='')
     def set_homedir(self, homedir):
         self.soundconf.set_homedir(homedir)
 
+    @dbus.service.method(INTERFACE, in_signature='s', out_signature='b')
+    def copy_file(self, filename):
+        des_path = '/var/lib/youker-assistant-daemon/custom'
+        filename = filename.encode('utf-8')
+        if not os.path.exists(des_path):
+            os.makedirs(des_path)
+        try:
+            shutil.copy(filename, des_path)
+            return True
+        except os.error:
+            pass
+        return False
+
+    @dbus.service.method(INTERFACE, in_signature='s', out_signature='b')
+    def delete_file(self, filename):
+        filename = filename.encode('utf-8')
+#        output = open("/tmp/default.txt", 'w+')
+#        output.write(filename)
+#        output.close()
+#        fp = open("/tmp/default.txt", "w")
+#        print >> fp, "--------------"
+#        print >> fp, filename
+#        print >> fp, "------22222222--------"
+#        fp.close()
+#        if os.path.exists(filename):
+        if os.path.isfile(filename):
+            try:
+                os.remove(filename)
+                return True
+            except os.error:
+                pass
+        return False
+
     # set cursor theme
     @dbus.service.method(INTERFACE, in_signature='s', out_signature='b')
     def set_cursor_theme_with_root(self, theme):
@@ -91,6 +249,12 @@ class Daemon(PolicyKitService):
         subprocess.Popen(cmd, shell=True, close_fds=True)#加上close_fds=True,避免子进程一直存在
         return True
 
+    @dbus.service.method(INTERFACE, in_signature='', out_signature='b')
+    def kill_uk_process(self):
+        cmd = 'killall youker-assistant'
+        subprocess.Popen(cmd, shell=True, close_fds=True)#加上close_fds=True,避免子进程一直存在
+        return True
+
     @dbus.service.method(INTERFACE, in_signature='s', out_signature='')
     def set_user_homedir(self, homedir):
         cleaner.get_user_homedir(homedir)
@@ -199,9 +363,9 @@ class Daemon(PolicyKitService):
     
     # -------------------------monitorball-------------------------
     # clean up memory
-    @dbus.service.method(INTERFACE, in_signature='', out_signature='')
-    def cleanup_memory(self):
-        self.ballconf.cleanup_memory()
+#    @dbus.service.method(INTERFACE, in_signature='', out_signature='')
+#    def cleanup_memory(self):
+#        self.ballconf.cleanup_memory()
     # -------------------------monitorball end-------------------------
 
     @dbus.service.signal(INTERFACE, signature='s')
@@ -431,15 +595,16 @@ class Daemon(PolicyKitService):
 #-----START-----------NEW-YOUKER---------------------------
 #
 
-    @dbus.service.method(INTERFACE, in_signature='a{sv}', out_signature='', sender_keyword='sender')
-    def remove_select_items(self, mode_dic, sender=None):
-        status = self._check_permission(sender, UK_ACTION_YOUKER)
-        if not status:
-            self.quit_clean(False)
-#            self.quit_clean_work()
-            return
-        else:
-            self.quit_clean(True)
+#    @dbus.service.method(INTERFACE, in_signature='a{sv}', out_signature='', sender_keyword='sender')
+#    def remove_select_items(self, mode_dic, sender=None):
+#        status = self._check_permission(sender, UK_ACTION_YOUKER)
+#        if not status:
+#            self.quit_clean(False)
+##            self.quit_clean_work()
+#            return
+#        else:
+#            self.quit_clean(True)
+    def start_clean_all(self, mode_dic):
         filecache = mode_dic.get('file', [])
         if filecache:
             for tmpName in filecache:
@@ -450,6 +615,16 @@ class Daemon(PolicyKitService):
             for pkgName in packagecache:
                 cleaner.interface_remove_package_system(self, pkgName)
 
+        bashhistory = mode_dic.get('bash-history', [])
+        if bashhistory:
+            for tmpName in bashhistory:
+                cleaner.interface_remove_file_system(self, tmpName)
+        
+        x11history = mode_dic.get('x11-history', [])
+        if bashhistory:
+            for tmpName in x11history:
+                cleaner.interface_remove_file_system(self, tmpName)
+
         firefoxhistory = mode_dic.get('firefox-history', [])
         if firefoxhistory:
             cleaner.interface_remove_firefox_history_system(self)
@@ -473,6 +648,16 @@ class Daemon(PolicyKitService):
                 cleaner.interface_remove_chromium_cookies_system(self, domain)
 
         self.subpage_status_signal('Complete:All', "finish")
+
+    @dbus.service.method(INTERFACE, in_signature='a{sv}', out_signature='', sender_keyword='sender')
+    def remove_select_items(self, mode_dic, sender=None):
+        status = self._check_permission(sender, UK_ACTION_YOUKER)
+        if not status:
+            self.quit_clean(False)
+            return
+        else:
+            self.quit_clean(True)
+        thread.start_new_thread(self.start_clean_all, (mode_dic,))
 #    @dbus.service.method(INTERFACE, in_signature='s', out_signature='', sender_keyword='sender')
 #    def remove_file(self, fp):
 #        status = self._check_permission(sender, UK_ACTION_YOUKER)
