@@ -34,6 +34,7 @@ class Toolkits;
 class MainWindow;
 class CleanSubGroup;
 
+
 namespace Ui {
 class CleanerDetailWidget;
 }
@@ -127,6 +128,12 @@ private:
     int subCount;
     bool scanResult;
     QString cur_skin;
+
+    int number_per_row;
+    int itemwidth;
+    int itemheight;
+    int cardspace;
+    QList <CleanSubGroup *> cardlist;
 };
 
 #endif // CLEANERDETAILWIDGET_H
