@@ -100,6 +100,12 @@ void SessionDispatcher::exit_qt() {
     sessioniface->call("exit");
 }
 
+QString SessionDispatcher::get_os_release_qt()
+{
+    QDBusReply<QString> reply = sessioniface->call("get_os_release");
+    return reply.value();
+}
+
 QStringList SessionDispatcher::checkNewVersion()
 {
     QDBusReply<QStringList> reply = sessioniface->call("currently_installed_version");
@@ -1148,6 +1154,11 @@ QString SessionDispatcher::access_current_desktop_qt() {
     return reply.value();
 }
 
+QString SessionDispatcher::access_current_machine_qt() {
+    QDBusReply<QString> reply = sessioniface->call("access_current_machine");
+    return reply.value();
+}
+
 //QString SessionDispatcher::judge_desktop_is_unity_qt() {
 //    QDBusReply<QString> reply = sessioniface->call("judge_desktop_is_unity");
 //    return reply.value();
