@@ -47,6 +47,8 @@ public:
     bool judge_power_is_exists_qt();
     QMap<QString, QVariant> read_battery_info_qt();
 
+    QString get_os_release_qt();
+
     //弹出登录框
     void popup_login_dialog();
     void popup_register_dialog();
@@ -263,6 +265,7 @@ public:
     void set_thumbnail_cache_size_qt(int size);
     int get_thumbnail_cache_size_qt();
     QString access_current_desktop_qt();
+    QString access_current_machine_qt();
 //    Q_INVOKABLE QString judge_desktop_is_unity_qt();
 //    Q_INVOKABLE QString judge_desktop_is_cinnamon_qt();
     //一键清理扫描
