@@ -32,7 +32,8 @@ class MonitorWidget : public QWidget
     Q_OBJECT
 public:
     explicit MonitorWidget(QWidget *parent = 0, SystemDispatcher *proxy = 0);
-    int initData();
+    void initData();
+    bool getStatus();
 
 signals:
 
@@ -43,7 +44,7 @@ private:
     QMap<QString, QVariant> monitor_info_map;
     QMap<QString, QVariant> tmp_info_map;
     SystemDispatcher *systemproxy;
-    int vgaNum;
+    bool dataOK;
 };
 
 #endif // MONITORWIDGET_H
