@@ -23,8 +23,8 @@
 //#include "../dbusproxy/youkersessiondbus.h"
 //#include "mainwindow.h"
 
-SettingWidget::SettingWidget(QWidget *parent) :
-    QWidget(parent)
+SettingWidget::SettingWidget(QString cur_desktop, bool has_battery, QWidget *parent) :
+    QWidget(parent), desktop(cur_desktop), battery(has_battery)
 {
     this->setFixedSize(900, 403);
     //set white background color
@@ -33,6 +33,8 @@ SettingWidget::SettingWidget(QWidget *parent) :
     palette.setBrush(QPalette::Window, QBrush(Qt::white));
     this->setPalette(palette);
 
+    this->qtui = NULL;
+
 //    this->mainwindow_width = 850;
 //    this->mainwindow_height = 600;
 
@@ -41,16 +43,17 @@ SettingWidget::SettingWidget(QWidget *parent) :
     icon_widget = NULL;
     mouse_widget = NULL;
     voice_widget = NULL;
-    animation_widget = NULL;
+//    animation_widget = NULL;
     launcher_widget = NULL;
     panel_widget = NULL;
     window_widget = NULL;
     font_widget = NULL;
     touchpad_widget = NULL;
-    deadpixel_widget = NULL;
+//    deadpixel_widget = NULL;
+    conserve_widget = NULL;
     nautilus_widget = NULL;
 
-    h_splitter = new QSplitter();
+    h_splitter = new QSplitter(this);
     h_splitter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     h_splitter->setOrientation(Qt::Horizontal);
     h_splitter->setHandleWidth(1);
@@ -105,39 +108,215 @@ SettingWidget::SettingWidget(QWidget *parent) :
 
 SettingWidget::~SettingWidget()
 {
-    if(stacked_widget != NULL)
+
+    if(individuation_icon != NULL)
     {
-        delete stacked_widget;
-        stacked_widget = NULL;
+        delete individuation_icon;
+        individuation_icon = NULL;
+    }
+    if(individuation_title != NULL)
+    {
+        delete individuation_title;
+        individuation_title = NULL;
+    }
+    if(dekstop_icon != NULL)
+    {
+        delete dekstop_icon;
+        dekstop_icon = NULL;
+    }
+    if(dekstop_title != NULL)
+    {
+        delete dekstop_title;
+        dekstop_title = NULL;
+    }
+
+
+
+    if(font_icon != NULL)
+    {
+        delete font_icon;
+        font_icon = NULL;
+    }
+    if(font_title != NULL)
+    {
+        delete font_title;
+        font_title = NULL;
+    }
+    if(option_icon != NULL)
+    {
+        delete option_icon;
+        option_icon = NULL;
+    }
+    if(option_title != NULL)
+    {
+        delete option_title;
+        option_title = NULL;
+    }
+    if(other_icon != NULL)
+    {
+        delete other_icon;
+        other_icon = NULL;
+    }
+    if(other_title != NULL)
+    {
+        delete other_title;
+        other_title = NULL;
+    }
+    if(dot1 != NULL)
+    {
+        delete dot1;
+        dot1 = NULL;
+    }
+    if(dot2 != NULL)
+    {
+        delete dot2;
+        dot2 = NULL;
+    }
+    if(dot3 != NULL)
+    {
+        delete dot3;
+        dot3 = NULL;
+    }
+    if(dot4 != NULL)
+    {
+        delete dot4;
+        dot4 = NULL;
+    }
+    if(dot6 != NULL)
+    {
+        delete dot6;
+        dot6 = NULL;
+    }
+    if(dot7 != NULL)
+    {
+        delete dot7;
+        dot7 = NULL;
+    }
+    if(dot8 != NULL)
+    {
+        delete dot8;
+        dot8 = NULL;
+    }
+    if(dot9 != NULL)
+    {
+        delete dot9;
+        dot9 = NULL;
+    }
+    if(dot10 != NULL)
+    {
+        delete dot10;
+        dot10 = NULL;
+    }
+    if(dot11 != NULL)
+    {
+        delete dot11;
+        dot11 = NULL;
+    }
+    if(dot12 != NULL)
+    {
+        delete dot12;
+        dot12 = NULL;
+    }
+    if(dot13 != NULL)
+    {
+        delete dot13;
+        dot13 = NULL;
+    }
+    if(theme_button != NULL)
+    {
+        delete theme_button;
+        theme_button = NULL;
+    }
+    if(icon_button != NULL)
+    {
+        delete icon_button;
+        icon_button = NULL;
+    }
+    if(mouse_button != NULL)
+    {
+        delete mouse_button;
+        mouse_button = NULL;
+    }
+    if(voice_button != NULL)
+    {
+        delete voice_button;
+        voice_button = NULL;
+    }
+    if(launcher_button != NULL)
+    {
+        delete launcher_button;
+        launcher_button = NULL;
+    }
+    if(panel_button != NULL)
+    {
+        delete panel_button;
+        panel_button = NULL;
+    }
+    if(window_button != NULL)
+    {
+        delete window_button;
+        window_button = NULL;
+    }
+    if(font_button != NULL)
+    {
+        delete font_button;
+        font_button = NULL;
+    }
+    if(touch_button != NULL)
+    {
+        delete touch_button;
+        touch_button = NULL;
+    }
+    if(pixel_button != NULL)
+    {
+        delete pixel_button;
+        pixel_button = NULL;
+    }
+    if(conserve_button != NULL)
+    {
+        delete conserve_button;
+        conserve_button = NULL;
+    }
+    if(nautilus_button != NULL)
+    {
+        delete nautilus_button;
+        nautilus_button = NULL;
+    }
+    if(qtui != NULL)
+    {
+        delete qtui;
+        qtui = NULL;
     }
 }
 
-void SettingWidget::initUI()
+void SettingWidget::initUI(QString skin)
 {
     theme_widget = new ThemeWidget(this, sessionProxy);
-    icon_widget = new IconWidget(this, sessionProxy);
-    mouse_widget = new MouseWidget(this, sessionProxy, systemProxy);
-    voice_widget = new VoiceWidget(this, sessionProxy, systemProxy);
-    animation_widget = new AnimationWidget(this, systemProxy, p_mainwindow);
-    launcher_widget = new LauncherWidget(this, sessionProxy);
-    panel_widget = new PanelWidget(this, sessionProxy);
-    window_widget = new WindowWidget(this, sessionProxy);
-    font_widget = new FontWidget(this, sessionProxy, p_mainwindow);
-    touchpad_widget = new TouchpadWidget(this, sessionProxy);
-    deadpixel_widget = new DeadpixelWidget(this);
+    icon_widget = new IconWidget(this, sessionProxy, desktop);
+    mouse_widget = new MouseWidget(this, sessionProxy, systemProxy, desktop);
+    voice_widget = new VoiceWidget(this, sessionProxy, systemProxy, desktop);
+//    animation_widget = new AnimationWidget(this, systemProxy, p_mainwindow);
+    launcher_widget = new LauncherWidget(this, sessionProxy, desktop);
+    panel_widget = new PanelWidget(this, sessionProxy, desktop, battery);
+    window_widget = new WindowWidget(this, sessionProxy, desktop);
+    font_widget = new FontWidget(this, sessionProxy, p_mainwindow, desktop, skin);
+    touchpad_widget = new TouchpadWidget(this, sessionProxy, desktop);
+//    deadpixel_widget = new DeadpixelWidget(this);
+    conserve_widget = new ConserveWidget(this, sessionProxy, desktop, battery);
     nautilus_widget = new NautilusWidget(this, sessionProxy);
     stacked_widget->addWidget(h_splitter);
     stacked_widget->addWidget(theme_widget);
     stacked_widget->addWidget(icon_widget);
     stacked_widget->addWidget(mouse_widget);
     stacked_widget->addWidget(voice_widget);
-    stacked_widget->addWidget(animation_widget);
+//    stacked_widget->addWidget(animation_widget);
     stacked_widget->addWidget(launcher_widget);
     stacked_widget->addWidget(panel_widget);
     stacked_widget->addWidget(window_widget);
     stacked_widget->addWidget(font_widget);
     stacked_widget->addWidget(touchpad_widget);
-    stacked_widget->addWidget(deadpixel_widget);
+//    stacked_widget->addWidget(deadpixel_widget);
+    stacked_widget->addWidget(conserve_widget);
     stacked_widget->addWidget(nautilus_widget);
 
     QHBoxLayout *main_layout = new QHBoxLayout();
@@ -146,8 +325,18 @@ void SettingWidget::initUI()
     main_layout->setContentsMargins(0, 0, 0, 0);
 
     this->setLayout(main_layout);
+
+//    connect(sessionProxy, SIGNAL(bool_value_notify(QString, bool)), this, SLOT(slot_notify_boolean(QString, bool)));
 }
 
+//void SettingWidget::slot_notify_boolean(QString key, bool value)
+//{
+//}
+void SettingWidget::resetSkin(QString skin)
+{
+    if(font_widget != NULL)
+        font_widget->resetCurrentSkin(skin);
+}
 
 void SettingWidget::initIndividuationWidget() {
     individuation_widget = new QWidget(this);
@@ -161,8 +350,8 @@ void SettingWidget::initIndividuationWidget() {
     mouse_button = new QPushButton();
     dot4 = new QLabel();
     voice_button = new QPushButton();
-    dot5 = new QLabel();
-    animation_button = new QPushButton();
+//    dot5 = new QLabel();
+//    animation_button = new QPushButton();
 
     theme_button->setFocusPolicy(Qt::NoFocus);
     theme_button->setObjectName("settingButton");
@@ -172,8 +361,8 @@ void SettingWidget::initIndividuationWidget() {
     mouse_button->setObjectName("settingButton");
     voice_button->setFocusPolicy(Qt::NoFocus);
     voice_button->setObjectName("settingButton");
-    animation_button->setFocusPolicy(Qt::NoFocus);
-    animation_button->setObjectName("settingButton");
+//    animation_button->setFocusPolicy(Qt::NoFocus);
+//    animation_button->setObjectName("settingButton");
 
     QHBoxLayout *title_layout = new QHBoxLayout();
     title_layout->addWidget(individuation_icon);
@@ -220,14 +409,14 @@ void SettingWidget::initIndividuationWidget() {
     layout4->setAlignment(dot4, Qt::AlignVCenter);
     layout4->setAlignment(voice_button, Qt::AlignVCenter);
 
-    QHBoxLayout *layout5 = new QHBoxLayout();
-    layout5->addWidget(dot5);
-    layout5->addWidget(animation_button);
-    layout5->addStretch();
-    layout5->setSpacing(5);
-    layout5->setContentsMargins(29, 0, 0, 0);
-    layout5->setAlignment(dot5, Qt::AlignVCenter);
-    layout5->setAlignment(animation_button, Qt::AlignVCenter);
+//    QHBoxLayout *layout5 = new QHBoxLayout();
+//    layout5->addWidget(dot5);
+//    layout5->addWidget(animation_button);
+//    layout5->addStretch();
+//    layout5->setSpacing(5);
+//    layout5->setContentsMargins(29, 0, 0, 0);
+//    layout5->setAlignment(dot5, Qt::AlignVCenter);
+//    layout5->setAlignment(animation_button, Qt::AlignVCenter);
 
     QVBoxLayout *v_layout = new QVBoxLayout();
     v_layout->addLayout(title_layout);
@@ -235,7 +424,7 @@ void SettingWidget::initIndividuationWidget() {
     v_layout->addLayout(layout2);
     v_layout->addLayout(layout3);
     v_layout->addLayout(layout4);
-    v_layout->addLayout(layout5);
+//    v_layout->addLayout(layout5);
     v_layout->addStretch();
     v_layout->setSpacing(10);
     v_layout->setContentsMargins(0, 0, 0, 0);
@@ -249,27 +438,27 @@ void SettingWidget::initIndividuationWidget() {
     dot2->setPixmap(QPixmap("://res/dot.png"));
     dot3->setPixmap(QPixmap("://res/dot.png"));
     dot4->setPixmap(QPixmap("://res/dot.png"));
-    dot5->setPixmap(QPixmap(":/res//dot.png"));
+//    dot5->setPixmap(QPixmap(":/res//dot.png"));
     theme_button->setStatusTip("theme");
     icon_button->setStatusTip("icon");
     mouse_button->setStatusTip("mouse");
     voice_button->setStatusTip("voice");
-    animation_button->setStatusTip("animation");
+//    animation_button->setStatusTip("animation");
     theme_button->setText(tr("ThemeSetting"));//主题设置
     icon_button->setText(tr("IconSetting"));//图标配置
     mouse_button->setText(tr("MousePointer"));//鼠标指针
     voice_button->setText(tr("SoundEffect"));//声音效果
-    animation_button->setText(tr("BootAnimation"));//开机动画
+//    animation_button->setText(tr("BootAnimation"));//开机动画
 
     connect(theme_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
     connect(icon_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
     connect(mouse_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
     connect(voice_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
-    connect(animation_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
+//    connect(animation_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
 }
 
 void SettingWidget::initDesktopWidget() {
-    dekstop_widget = new QWidget();
+    dekstop_widget = new QWidget(this);
     dekstop_icon = new QLabel();
     dekstop_title = new QLabel();
     dot6 = new QLabel();
@@ -339,8 +528,14 @@ void SettingWidget::initDesktopWidget() {
     dot6->setPixmap(QPixmap("://res/dot.png"));
     dot7->setPixmap(QPixmap("://res/dot.png"));
     dot8->setPixmap(QPixmap("://res/dot.png"));
-    launcher_button->setText(tr("Custom Launcher"));//自定义启动器
-    panel_button->setText(tr("Dash & Panel"));//搜索和面板
+    if (this->desktop == "mate") {
+        launcher_button->setText(tr("Panel"));//面板
+        panel_button->setText(tr("StartMenu"));//启动菜单
+    }
+    else {
+        launcher_button->setText(tr("Custom Launcher"));//自定义启动器
+        panel_button->setText(tr("Dash & Panel"));//搜索和面板
+    }
     window_button->setText(tr("Window"));//窗口
     launcher_button->setStatusTip("launcher");
     panel_button->setStatusTip("panel");
@@ -352,7 +547,7 @@ void SettingWidget::initDesktopWidget() {
 }
 
 void SettingWidget::initFontWidget() {
-    fonts_widget = new QWidget();
+    fonts_widget = new QWidget(this);
     font_icon = new QLabel();
     font_title = new QLabel();
     dot9 = new QLabel();
@@ -398,18 +593,22 @@ void SettingWidget::initFontWidget() {
 }
 
 void SettingWidget::initOptionWidget() {
-    option_widget = new QWidget();
+    option_widget = new QWidget(this);
     option_icon = new QLabel();
     option_title = new QLabel();
     dot10 = new QLabel();
     touch_button = new QPushButton();
     dot11 = new QLabel();
     pixel_button = new QPushButton();
+    dot12 = new QLabel();
+    conserve_button = new QPushButton();
 
     touch_button->setFocusPolicy(Qt::NoFocus);
     touch_button->setObjectName("settingButton");
     pixel_button->setFocusPolicy(Qt::NoFocus);
     pixel_button->setObjectName("settingButton");
+    conserve_button->setFocusPolicy(Qt::NoFocus);
+    conserve_button->setObjectName("settingButton");
 
     QHBoxLayout *title_layout = new QHBoxLayout();
     title_layout->addWidget(option_icon);
@@ -438,10 +637,20 @@ void SettingWidget::initOptionWidget() {
     layout11->setAlignment(dot11, Qt::AlignVCenter);
     layout11->setAlignment(pixel_button, Qt::AlignVCenter);
 
+    QHBoxLayout *layout12 = new QHBoxLayout();
+    layout12->addWidget(dot12);
+    layout12->addWidget(conserve_button);
+    layout12->addStretch();
+    layout12->setSpacing(5);
+    layout12->setContentsMargins(29, 0, 0, 0);
+    layout12->setAlignment(dot12, Qt::AlignVCenter);
+    layout12->setAlignment(conserve_button, Qt::AlignVCenter);
+
     QVBoxLayout *v_layout = new QVBoxLayout();
     v_layout->addLayout(title_layout);
     v_layout->addLayout(layout10);
     v_layout->addLayout(layout11);
+    v_layout->addLayout(layout12);
     v_layout->addStretch();
     v_layout->setSpacing(10);
     v_layout->setContentsMargins(0, 0, 0, 0);
@@ -452,21 +661,26 @@ void SettingWidget::initOptionWidget() {
     option_title->setText(tr("Sys options"));//系统选项
     dot10->setPixmap(QPixmap("://res/dot.png"));
     dot11->setPixmap(QPixmap("://res/dot.png"));
+    dot12->setPixmap(QPixmap("://res/dot.png"));
     touch_button->setText(tr("Touchpad"));//触摸板设置
     pixel_button->setText(tr("Dead pixel check"));//坏点检测
+    conserve_button->setText(tr("Energy saving"));
     touch_button->setStatusTip("touchpad");
     pixel_button->setStatusTip("deadpixel");
+    conserve_button->setStatusTip("conserve");
 
     connect(touch_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
-    connect(pixel_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
+//    connect(pixel_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
+    connect(pixel_button, SIGNAL(clicked()), this, SLOT(startMonitorCheck()));
+    connect(conserve_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
 //    connect(pixel_button, SIGNAL(clicked()), this, SLOT(showCheckscreenDialog()));
 }
 
 void SettingWidget::initOtherWidget() {
-    other_widget = new QWidget();
+    other_widget = new QWidget(this);
     other_icon = new QLabel();
     other_title = new QLabel();
-    dot12 = new QLabel();
+    dot13 = new QLabel();
     nautilus_button = new QPushButton();
 
     nautilus_button->setFocusPolicy(Qt::NoFocus);
@@ -482,18 +696,18 @@ void SettingWidget::initOtherWidget() {
     title_layout->setAlignment(other_icon, Qt::AlignVCenter);
     title_layout->setAlignment(other_title, Qt::AlignVCenter);
 
-    QHBoxLayout *layout12 = new QHBoxLayout();
-    layout12->addWidget(dot12);
-    layout12->addWidget(nautilus_button);
-    layout12->addStretch();
-    layout12->setSpacing(5);
-    layout12->setContentsMargins(29, 0, 0, 0);
-    layout12->setAlignment(dot12, Qt::AlignVCenter);
-    layout12->setAlignment(nautilus_button, Qt::AlignVCenter);
+    QHBoxLayout *layout13 = new QHBoxLayout();
+    layout13->addWidget(dot13);
+    layout13->addWidget(nautilus_button);
+    layout13->addStretch();
+    layout13->setSpacing(5);
+    layout13->setContentsMargins(29, 0, 0, 0);
+    layout13->setAlignment(dot13, Qt::AlignVCenter);
+    layout13->setAlignment(nautilus_button, Qt::AlignVCenter);
 
     QVBoxLayout *v_layout = new QVBoxLayout();
     v_layout->addLayout(title_layout);
-    v_layout->addLayout(layout12);
+    v_layout->addLayout(layout13);
     v_layout->addStretch();
     v_layout->setSpacing(10);
     v_layout->setContentsMargins(0, 0, 0, 0);
@@ -502,13 +716,22 @@ void SettingWidget::initOtherWidget() {
 
     other_icon->setPixmap(QPixmap("://res/other.png"));
     other_title->setText(tr("Others"));//杂项
-    dot12->setPixmap(QPixmap("://res/dot.png"));
+    dot13->setPixmap(QPixmap("://res/dot.png"));
     nautilus_button->setText(tr("File manager"));//文件管理器
     nautilus_button->setStatusTip("nautilus");
 
     connect(nautilus_button, SIGNAL(clicked()), this, SLOT(displaySettingSubPage()));
 }
 
+void SettingWidget::startMonitorCheck() {
+    if (this->qtui)
+    {
+        delete this->qtui;
+        this->qtui = NULL;
+    }
+    this->qtui = new QUIBO();
+}
+
 void SettingWidget::displaySettingHomePage() {
     stacked_widget->setCurrentIndex(0);
 }
@@ -522,51 +745,91 @@ void SettingWidget::displaySettingSubPage() {
     QPushButton *btn = qobject_cast<QPushButton *>(object);
     QString object_name = btn->statusTip();
     if (object_name == "theme") {
-        stacked_widget->setCurrentIndex(1);
         emit changeActionPage(1);
+        if(!theme_widget->getStatus())
+            theme_widget->initData();
+//        stacked_widget->setCurrentIndex(1);
+        stacked_widget->setCurrentWidget(theme_widget);
     }
     else if (object_name == "icon") {
-        stacked_widget->setCurrentIndex(2);
         emit changeActionPage(2);
+        if(!icon_widget->getStatus())
+            icon_widget->initData();
+//        stacked_widget->setCurrentIndex(2);
+        stacked_widget->setCurrentWidget(icon_widget);
     }
     else if (object_name == "mouse") {
-        stacked_widget->setCurrentIndex(3);
         emit changeActionPage(3);
+        if(!mouse_widget->getStatus())
+            mouse_widget->initData();
+//        stacked_widget->setCurrentIndex(3);
+        stacked_widget->setCurrentWidget(mouse_widget);
     }
     else if (object_name == "voice") {
-        stacked_widget->setCurrentIndex(4);
         emit changeActionPage(4);
+        if(!voice_widget->getStatus())
+            voice_widget->initData();
+//        stacked_widget->setCurrentIndex(4);
+        stacked_widget->setCurrentWidget(voice_widget);
     }
-    else if (object_name == "animation") {
-        stacked_widget->setCurrentIndex(5);
-        emit changeActionPage(5);
-    }
+//    else if (object_name == "animation") {
+//        emit changeActionPage(5);
+//        if(!animation_widget->getStatus())
+//            animation_widget->initData();
+//        stacked_widget->setCurrentIndex(5);
+//    }
+
     else if (object_name == "launcher") {
-        stacked_widget->setCurrentIndex(6);
-        emit changeActionPage(6);
+        emit changeActionPage(5);
+        if(!launcher_widget->getStatus())
+            launcher_widget->initData();
+//        stacked_widget->setCurrentIndex(5);
+        stacked_widget->setCurrentWidget(launcher_widget);
     }
     else if (object_name == "panel") {
-        stacked_widget->setCurrentIndex(7);
-        emit changeActionPage(7);
+        emit changeActionPage(6);
+        if(!panel_widget->getStatus())
+            panel_widget->initData();
+//        stacked_widget->setCurrentIndex(6);
+        stacked_widget->setCurrentWidget(panel_widget);
     }
     else if (object_name == "window") {
-        stacked_widget->setCurrentIndex(8);
-        emit changeActionPage(8);
+        emit changeActionPage(7);
+        if(!window_widget->getStatus())
+            window_widget->initData();
+//        stacked_widget->setCurrentIndex(7);
+        stacked_widget->setCurrentWidget(window_widget);
     }
     else if (object_name == "font") {
-        stacked_widget->setCurrentIndex(9);
-        emit changeActionPage(9);
+        emit changeActionPage(8);
+        if(!font_widget->getStatus())
+            font_widget->initData();
+//        stacked_widget->setCurrentIndex(8);
+        stacked_widget->setCurrentWidget(font_widget);
     }
     else if (object_name == "touchpad") {
-        stacked_widget->setCurrentIndex(10);
-        emit changeActionPage(10);
+        emit changeActionPage(9);
+        if(!touchpad_widget->getStatus())
+            touchpad_widget->initData();
+//        stacked_widget->setCurrentIndex(9);
+        stacked_widget->setCurrentWidget(touchpad_widget);
     }
-    else if (object_name == "deadpixel") {
-        stacked_widget->setCurrentIndex(11);
+//    else if (object_name == "deadpixel") {
+//        emit changeActionPage(10);
+//        stacked_widget->setCurrentIndex(10);
+//    }
+    else if (object_name == "conserve") {
         emit changeActionPage(11);
+        if(!conserve_widget->getStatus())
+            conserve_widget->initData();
+//        stacked_widget->setCurrentIndex(11);
+        stacked_widget->setCurrentWidget(conserve_widget);
     }
     else if (object_name == "nautilus") {
-        stacked_widget->setCurrentIndex(12);
         emit changeActionPage(12);
+        if(!nautilus_widget->getStatus())
+            nautilus_widget->initData();
+//        stacked_widget->setCurrentIndex(12);
+        stacked_widget->setCurrentWidget(nautilus_widget);
     }
 }
